"Xarchie*archieHost:	archie.sura.net(1526)",
"Xarchie*searchType:	exact",
"Xarchie*sortType:	name",
"Xarchie*maxHits:	99",
"Xarchie*offset:		0",
"Xarchie*timeout:	4",
"Xarchie*retries:	3",
"Xarchie*niceLevel:	0",
"Xarchie*ftpMailAddress:	%s@%s",
"Xarchie*ftpType:	binary",
"Xarchie*ftpPrompt:	True",
"Xarchie*ftpTrace:	False",
"Xarchie*ftpStrip:	True",
"Xarchie*fileWriteOnePerLine:	False",
"Xarchie*autoScroll:	True",
"Xarchie*pasteBuffer:	True",
"Xarchie*debugLevel:	0",
"Xarchie*xarchieFont:		*-fixed-medium-r-*-*-13-*-*-*-*-*-iso8859-*",
"Xarchie*xarchieBoldFont:	*-fixed-bold-r-*-*-13-*-*-*-*-*-iso8859-*",
"Xarchie*input:			True",
"Xarchie*outerPaned*Form.translations:#override\\n\
	Meta<Key>a:	about()\\n\
	Meta<Key>o:	browser-open-all()\\n\
	Meta<Key>g:	ftp-get()\\n\
	Meta<Key>s:	file-save()\\n\
	Meta<Key>l:	file-load()\\n\
	Meta<Key>w:	file-write()\\n\
	Meta<Key>q:	quit()\\n",
"Xarchie*Viewport*allowVert:		True",
"Xarchie*Viewport*allowHoriz:		False",
"Xarchie*Viewport*forceBars:		True",
"Xarchie*Viewport.preferredPaneSize:	160",
"Xarchie*Viewport.vertical.width:	15",
"Xarchie*XfwfMultiList*font:		xarchieFont",
"Xarchie*XfwfMultiList*verticalList:	True",
"Xarchie*XfwfMultiList*defaultColumns:	1",
"Xarchie*XfwfMultiList*forceColumns:	True",
"Xarchie*XfwfMultiList*shadeSurplus:	False",
"Xarchie*XfwfMultiList*maxSelectable:	99",
"Xarchie*XfwfMultiList*height:		150",
"Xarchie*XfwfMultiList*translations:#replace\\n\
	Shift<Btn1Down>(2):	browser-open-directories() \\n\
	<Btn1Down>(2):		browser-open-directories() \\n\
	Shift<Btn1Down>:	Toggle() Notify() \\n\
	<Btn1Down>:	 	Select() Notify() \\n\
	<Btn2Down>,<Btn2Up>:	browser-up()\\n\
	<Btn3Down>,<Btn3Up>:	browser-down()\\n\
	<Key>Right:		browser-down()\\n\
	<Key>Left:		browser-up()\\n\
	<Key>Home:		browser-top()\\n\
	Meta<Key>a:		about()\\n\
	Meta<Key>o:		browser-open-all()\\n\
	Meta<Key>g:		ftp-get()\\n\
	Meta<Key>s:		file-save()\\n\
	Meta<Key>l:		file-load()\\n\
	Meta<Key>w:		file-write()\\n\
	Meta<Key>q:		quit()\\n",
"Xarchie*List*font:		xarchieFont",
"Xarchie*List*verticalList:	True",
"Xarchie*List*height:		150",
"Xarchie*Grip*height:		5",
"Xarchie*Grip*width:		5",
"Xarchie*Label.borderWidth:		0",
"Xarchie*Label.internalWidth:		0",
"Xarchie*Text*Label.internalWidth:	1",
"Xarchie*Label.resize:			True",
"Xarchie*Label.resizable:		True",
"Xarchie*Text*borderWidth:		1",
"Xarchie*Text*font:			xarchieFont",
"Xarchie*Text*Scrollbar.thickness: 	5",
"Xarchie*Text*editType:			edit",
"Xarchie*Text.scrollHorizontal:		whenNeeded",
"Xarchie*Text*Text.scrollHorizontal:	never",
"Xarchie*Text.displayCaret:	False",
"Xarchie*Text.translations:#override\\n\
	<Enter>:	display-caret(True) \\n\
	<Leave>:	display-caret(False) \\n\
	<Key>Return:	no-op() \\n",
"Xarchie.translations:#override\\n\
	<Message>WM_PROTOCOLS:	quit()\\n",
"Xarchie*outerPaned.orientation:	vertical",
"Xarchie*buttonForm.skipAdjust: True",
"Xarchie*buttonForm.showGrip: False",
"Xarchie*buttonForm*fileButton.label:		File>",
"Xarchie*buttonForm*fileButton.menuName:		fileMenu",
"Xarchie*buttonForm*settingsButton.label:	Settings>",
"Xarchie*buttonForm*settingsButton.menuName:	settingsMenu",
"Xarchie*buttonForm*settingsButton.fromHoriz:	fileButton",
"Xarchie*buttonForm*queryButton.label:		Query>",
"Xarchie*buttonForm*queryButton.menuName:	queryMenu",
"Xarchie*buttonForm*queryButton.fromHoriz:	settingsButton",
"Xarchie*buttonForm*abortButton.label:		Abort",
"Xarchie*buttonForm*abortButton.fromHoriz:	queryButton",
"Xarchie*buttonForm*abortButton.translations:#override\\n\
	<BtnDown>,<BtnUp>:	abort()\\n",
"Xarchie*buttonForm*helpButton.label:		Help",
"Xarchie*buttonForm*helpButton.fromHoriz:	abortButton",
"Xarchie*buttonForm*helpButton.translations:#override\\n\
	<BtnDown>,<BtnUp>:	help()\\n",
"Xarchie*buttonForm*statusLabel.label:		Status:",
"Xarchie*buttonForm*statusLabel.fromVert:	fileButton",
"Xarchie*buttonForm*statusText.fromHoriz:	statusLabel",
"Xarchie*buttonForm*statusText.fromVert:		fileButton",
"Xarchie*buttonForm*statusText*width:		410",
"Xarchie*buttonForm*statusText*editType:		read",
"Xarchie*buttonForm*statusText.borderWidth:	0",
"Xarchie*buttonForm*statusText*scrollHorizontal:	never",
"Xarchie*buttonForm*statusText*translations:#override\\n",
"Xarchie*buttonForm*statusScrollbar.fromVert:	statusText",
"Xarchie*buttonForm*statusScrollbar.fromHoriz:	statusLabel",
"Xarchie*buttonForm*statusScrollbar.orientation:	horizontal",
"Xarchie*buttonForm*statusScrollbar.length:	410",
"Xarchie*browserForm.borderWidth:		0",
"Xarchie*browserForm.defaultDistance:		0",
"Xarchie*browserForm*Command.width:		240",
"Xarchie*browserForm*Command.justify:		center",
"Xarchie*browserForm*Command.borderWidth:	0",
"Xarchie*browserForm*Command.internalHeight:	2",
"Xarchie*browserForm*Command.top:		chainTop",
"Xarchie*browserForm*Command.bottom:		chainTop",
"Xarchie*browserForm.browserUpButton.label:	<<<",
"Xarchie*browserForm.browserUpButton.translations:#override\\n\
	Shift<BtnDown>,<BtnUp>:	browser-top() \\n\
	<BtnDown>,<BtnUp>:	browser-up() \\n",
"Xarchie*browserForm.browserDownButton.label:	>>>",
"Xarchie*browserForm.browserDownButton.fromHoriz:browserUpButton",
"Xarchie*browserForm.browserDownButton.translations:#override\\n\
	<BtnDown>,<BtnUp>:	browser-down() \\n",
"Xarchie*browserForm.browserPaned.orientation:	horizontal",
"Xarchie*browserForm.browserPaned.fromVert:	browserDownButton",
"Xarchie*browserForm.browserPaned.top:		chainTop",
"Xarchie*browserForm.browserPaned.showGrip:	False",
"Xarchie*browserForm*List*defaultColumns:	1",
"Xarchie*browserForm*List*forceColumns:		True",
"Xarchie*browserForm*List.translations:#override\\n\
	<Btn1Down>(2):		browser-open-directories() \\n\
	<Btn1Down>,<Btn1Up>:	Set() Notify() \\n",
"Xarchie*stringForm.skipAdjust: True",
"Xarchie*stringForm*Label.justify:	left",
"Xarchie*stringForm*Label.font:		xarchieFont",
"Xarchie*stringForm*AsciiSrc.editType: 	read",
"Xarchie*stringForm*searchLabel.label:		Search Term:",
"Xarchie*stringForm*searchLabel.font:  		xarchieBoldFont",
"Xarchie*stringForm*searchText*width:		390",
"Xarchie*stringForm*searchText.fromHoriz:	searchLabel",
"Xarchie*stringForm*searchText*editType: 	edit",
"Xarchie*stringForm*searchText.translations:#override\\n\
	<Enter>:	display-caret(True) \\n\
	<Leave>:	display-caret(False) \\n\
	<Key>Return:	query() \\n",
"Xarchie*stringForm*hostLabel.label:	Host:",
"Xarchie*stringForm*hostText.width:	438",
"Xarchie*stringForm*hostLabel.fromVert:	searchLabel",
"Xarchie*stringForm*hostText.fromVert:	searchLabel",
"Xarchie*stringForm*hostText.fromHoriz:	hostLabel",
"Xarchie*stringForm*hostText*editType: 	edit",
"Xarchie*stringForm*hostText.translations:#override\\n\
	<Enter>:	display-caret(True) \\n\
	<Leave>:	display-caret(False) \\n\
	<Key>Return:	query-host() \\n",
"Xarchie*stringForm*locationLabel.label:		Location:",
"Xarchie*stringForm*locationText.width:		410",
"Xarchie*stringForm*locationText.height:		20",
"Xarchie*stringForm*locationLabel.fromVert:	hostLabel",
"Xarchie*stringForm*locationText.fromHoriz:	locationLabel",
"Xarchie*stringForm*locationText.fromVert:	hostLabel",
"Xarchie*stringForm*locationText*editType: 	edit",
"Xarchie*stringForm*locationText.translations:#override\\n\
	<Enter>:	display-caret(True) \\n\
	<Leave>:	display-caret(False) \\n\
	<Key>Return:	query-location() \\n",
"Xarchie*stringForm*fileLabel.label:	File:",
"Xarchie*stringForm*fileLabel.fromVert:	locationText",
"Xarchie*stringForm*fileText.fromHoriz:	fileLabel",
"Xarchie*stringForm*fileText.fromVert:	locationText",
"Xarchie*stringForm*fileText.width:	438",
"Xarchie*stringForm*sizeLabel.label:	Size:",
"Xarchie*stringForm*sizeLabel.fromVert:	fileLabel",
"Xarchie*stringForm*sizeText.fromHoriz:	sizeLabel",
"Xarchie*stringForm*sizeText.fromVert:	fileLabel",
"Xarchie*stringForm*sizeText*width:	112",
"Xarchie*stringForm*modesLabel.label:	Mode:",
"Xarchie*stringForm*modesLabel.fromHoriz:sizeText",
"Xarchie*stringForm*modesLabel.fromVert:	fileLabel",
"Xarchie*stringForm*modesText.fromHoriz:	modesLabel",
"Xarchie*stringForm*modesText.fromVert:	fileLabel",
"Xarchie*stringForm*modesText*width:	112",
"Xarchie*stringForm*dateLabel.label:	Date:",
"Xarchie*stringForm*dateLabel.fromHoriz:	modesText",
"Xarchie*stringForm*dateLabel.fromVert:	fileLabel",
"Xarchie*stringForm*dateText.fromHoriz:	dateLabel",
"Xarchie*stringForm*dateText.fromVert:	fileLabel",
"Xarchie*stringForm*dateText*width:	125",
"Xarchie*settingsForm*Text*borderWidth:		1",
"Xarchie*settingsForm*Label.resizable:		True",
"Xarchie*settingsShell.title:			Xarchie Settings Panel",
"Xarchie*settingsShell.translations:#override\\n\
	<Message>WM_PROTOCOLS:	settings-done()\\n",
"Xarchie*settingsForm*setDoneButton.label:	Done",
"Xarchie*settingsForm*setDoneButton.translations:#override\\n\
	<BtnDown>,<BtnUp>:	settings-done() \\n",
"Xarchie*settingsForm*setApplyButton.label:	Apply",
"Xarchie*settingsForm*setApplyButton.fromHoriz:	setDoneButton",
"Xarchie*settingsForm*setApplyButton.translations:#override\\n\
	<BtnDown>,<BtnUp>:	settings-apply() \\n",
"Xarchie*settingsForm*setDefaultButton.label:	Default",
"Xarchie*settingsForm*setDefaultButton.fromHoriz:setApplyButton",
"Xarchie*settingsForm*setDefaultButton.translations:#override\\n\
	<BtnDown>,<BtnUp>:	settings-default() \\n",
"Xarchie*settingsForm*setHostButton.label:	Host",
"Xarchie*settingsForm*setHostButton.menuName:	setHostMenu",
"Xarchie*settingsForm*setHostButton.fromVert:	setApplyButton",
"Xarchie*settingsForm*setHostButton.vertDistance:10",
"Xarchie*settingsForm*setHostText.fromVert:	setApplyButton",
"Xarchie*settingsForm*setHostText.vertDistance:	10",
"Xarchie*settingsForm*setHostText.fromHoriz:	setHostButton",
"Xarchie*settingsForm*setHostText.width:		353",
"Xarchie*settingsForm*setSearchButton.label:	Search Mode",
"Xarchie*settingsForm*setSearchButton.menuName:	setSearchMenu",
"Xarchie*settingsForm*setSearchButton.fromVert:	setHostButton",
"Xarchie*settingsForm*setSearchLabel.fromVert:	setHostButton",
"Xarchie*settingsForm*setSearchLabel.fromHoriz:	setSearchButton",
"Xarchie*settingsForm*setSearchLabel.font: 	xarchieFont",
"Xarchie*settingsForm*setSortButton.label:	Sort Mode",
"Xarchie*settingsForm*setSortButton.menuName:	setSortMenu",
"Xarchie*settingsForm*setSortButton.fromVert:	setHostButton",
"Xarchie*settingsForm*setSortButton.fromHoriz:	setSearchButton",
"Xarchie*settingsForm*setSortButton.horizDistance:100",
"Xarchie*settingsForm*setSortLabel.fromVert:	setHostButton",
"Xarchie*settingsForm*setSortLabel.fromHoriz:	setSortButton",
"Xarchie*settingsForm*setSortLabel.font: 	xarchieFont",
"Xarchie*settingsForm*setNiceButton.label:	Nice Level",
"Xarchie*settingsForm*setNiceButton.menuName:	setNiceMenu",
"Xarchie*settingsForm*setNiceButton.fromVert:	setSortButton",
"Xarchie*settingsForm*setNiceText.fromVert:	setSortButton",
"Xarchie*settingsForm*setNiceText.fromHoriz:	setNiceButton",
"Xarchie*settingsForm*setNiceText.width:		82",
"Xarchie*settingsForm*setMaxHitsLabel.label:	Max Hits:",
"Xarchie*settingsForm*setMaxHitsLabel.fromVert:	setNiceButton",
"Xarchie*settingsForm*setMaxHitsText.fromVert:	setNiceButton",
"Xarchie*settingsForm*setMaxHitsText.fromHoriz:	setMaxHitsLabel",
"Xarchie*settingsForm*setMaxHitsText.width:	99",
"Xarchie*settingsForm*setTimeoutLabel.label:	Initial Timeout:",
"Xarchie*settingsForm*setTimeoutLabel.fromVert:	setMaxHitsLabel",
"Xarchie*settingsForm*setTimeoutText.fromVert:	setMaxHitsLabel",
"Xarchie*settingsForm*setTimeoutText.fromHoriz:	setTimeoutLabel",
"Xarchie*settingsForm*setTimeoutText.width:	50",
"Xarchie*settingsForm*setRetriesLabel.label:	Retries:",
"Xarchie*settingsForm*setRetriesLabel.fromVert:	setTimeoutLabel",
"Xarchie*settingsForm*setRetriesText.fromVert:	setTimeoutLabel",
"Xarchie*settingsForm*setRetriesText.fromHoriz:	setRetriesLabel",
"Xarchie*settingsForm*setRetriesText.width:	106",
"Xarchie*settingsForm*setAutoScrollButton.label:		Auto-Scroll Browser:",
"Xarchie*settingsForm*setAutoScrollButton.menuName:	setAutoScrollMenu",
"Xarchie*settingsForm*setAutoScrollButton.fromVert:	setRetriesLabel",
"Xarchie*settingsForm*setAutoScrollButton.vertDistance:	20",
"Xarchie*settingsForm*setAutoScrollLabel.fromVert:	setRetriesLabel",
"Xarchie*settingsForm*setAutoScrollLabel.vertDistance:	20",
"Xarchie*settingsForm*setAutoScrollLabel.fromHoriz:	setAutoScrollButton",
"Xarchie*settingsForm*setAutoScrollLabel.font: 		xarchieFont",
"Xarchie*settingsForm*ftpMailAddressLabel.label:		FTP Email Address:",
"Xarchie*settingsForm*ftpMailAddressLabel.fromVert:	setAutoScrollLabel",
"Xarchie*settingsForm*ftpMailAddressLabel.vertDistance:	20",
"Xarchie*settingsForm*ftpMailAddressText.fromHoriz:	ftpMailAddressLabel",
"Xarchie*settingsForm*ftpMailAddressText.fromVert:	setAutoScrollLabel",
"Xarchie*settingsForm*ftpMailAddressText.vertDistance:	20",
"Xarchie*settingsForm*ftpMailAddressText.width:		264",
"Xarchie*settingsForm*ftpLocalDirLabel.label:	FTP Local Directory:",
"Xarchie*settingsForm*ftpLocalDirLabel.fromVert:	ftpMailAddressLabel",
"Xarchie*settingsForm*ftpLocalDirText.fromHoriz:	ftpLocalDirLabel",
"Xarchie*settingsForm*ftpLocalDirText.fromVert:	ftpMailAddressLabel",
"Xarchie*settingsForm*ftpLocalDirText.width:	250",
"Xarchie*settingsForm*ftpTypeButton.label:	FTP Transfer Type:",
"Xarchie*settingsForm*ftpTypeButton.menuName:	ftpTypeMenu",
"Xarchie*settingsForm*ftpTypeButton.fromVert:	ftpLocalDirLabel",
"Xarchie*settingsForm*ftpTypeLabel.fromHoriz:	ftpTypeButton",
"Xarchie*settingsForm*ftpTypeLabel.fromVert:	ftpLocalDirLabel",
"Xarchie*settingsForm*ftpTypeLabel.font: 	xarchieFont",
"Xarchie*settingsForm*ftpPromptButton.label:	Prompt during FTP:",
"Xarchie*settingsForm*ftpPromptButton.menuName:	ftpPromptMenu",
"Xarchie*settingsForm*ftpPromptButton.fromHoriz:	ftpTypeLabel",
"Xarchie*settingsForm*ftpPromptButton.horizDistance: 20",
"Xarchie*settingsForm*ftpPromptButton.fromVert:	ftpLocalDirLabel",
"Xarchie*settingsForm*ftpPromptLabel.fromHoriz:	ftpPromptButton",
"Xarchie*settingsForm*ftpPromptLabel.fromVert:	ftpLocalDirLabel",
"Xarchie*settingsForm*ftpPromptLabel.font:	xarchieFont",
"Xarchie*settingsForm*ftpTraceButton.label:	Trace FTP Transfers:",
"Xarchie*settingsForm*ftpTraceButton.menuName:	ftpTraceMenu",
"Xarchie*settingsForm*ftpTraceButton.fromVert:	ftpTypeButton",
"Xarchie*settingsForm*ftpTraceLabel.fromHoriz:	ftpTraceButton",
"Xarchie*settingsForm*ftpTraceLabel.fromVert:	ftpTypeButton",
"Xarchie*settingsForm*ftpTraceLabel.font:	xarchieFont",
"Xarchie*settingsForm*ftpStripButton.label:	Strip CR:",
"Xarchie*settingsForm*ftpStripButton.menuName:	ftpStripMenu",
"Xarchie*settingsForm*ftpStripButton.fromVert:	ftpTypeButton",
"Xarchie*settingsForm*ftpStripButton.fromHoriz:	ftpTraceButton",
"Xarchie*settingsForm*ftpStripButton.horizDistance: 52",
"Xarchie*settingsForm*ftpStripLabel.fromHoriz:	ftpStripButton",
"Xarchie*settingsForm*ftpStripLabel.fromVert:	ftpTypeButton",
"Xarchie*settingsForm*ftpStripLabel.font:	xarchieFont",
"Xarchie*settingsForm*setHostWeightsLabel.label:		Host weights:",
"Xarchie*settingsForm*setHostWeightsLabel.fromVert:	setSortButton",
"Xarchie*settingsForm*setHostWeightsLabel.fromHoriz:	setSearchButton",
"Xarchie*settingsForm*setHostWeightsLabel.horizDistance:	100",
"Xarchie*settingsForm*setHostWeightsLabel.mappedWhenManaged: False",
"Xarchie*settingsForm*setHostWeightsText.borderWidth:	1",
"Xarchie*settingsForm*setHostWeightsText.fromVert:	setHostWeightsLabel",
"Xarchie*settingsForm*setHostWeightsText.fromHoriz:	setSearchButton",
"Xarchie*settingsForm*setHostWeightsText.horizDistance:	100",
"Xarchie*settingsForm*setHostWeightsText.mappedWhenManaged: False",
"Xarchie*settingsForm*setHostWeightsText.height:		60",
"Xarchie*settingsForm*setHostWeightsText.width:		205",
"Xarchie*settingsForm*setHostWeightsText.scrollVertical:	always",
"Xarchie*settingsForm*setHostWeightsText.scrollHorizontal: whenNeeded",
"Xarchie*settingsForm*setHostWeightsText.translations:#override\\n\
	<Key>Return:	newline() \\n",
"Xarchie*filePanelShell.title:		Xarchie File Panel",
"Xarchie*filePanelForm*Text*borderWidth:		1",
"Xarchie*filePanelForm*Label*resizable:		True",
"Xarchie*filePanelLabel.borderWidth:		0",
"Xarchie*filePanelWriteModeButton.label:		Write Format",
"Xarchie*filePanelWriteModeButton.menuName:	filePanelWriteModeMenu",
"Xarchie*filePanelWriteModeButton.fromHoriz:	filePanelLabel",
"Xarchie*filePanelWriteModeButton.horizDistance:	20",
"Xarchie*filePanelWriteModeLabel.font: 		xarchieFont",
"Xarchie*filePanelWriteModeLabel.fromHoriz:	filePanelWriteModeButton",
"Xarchie*filePanelFileChooser.width:		343",
"Xarchie*filePanelFileChooser.fromVert:		filePanelWriteModeButton",
"Xarchie*filePanelTextLabel.label:		File:",
"Xarchie*filePanelText.width:			305",
"Xarchie*filePanelText.fromHoriz:		filePanelTextLabel",
"Xarchie*filePanelText.fromVert:			filePanelFileChooser",
"Xarchie*filePanelText.translations:#override\\n\
	<Enter>:	display-caret(True) \\n\
	<Leave>:	display-caret(False) \\n\
	<Key>Return:	no-op()\\n",
"Xarchie*filePanelOkButton.label:		Ok",
"Xarchie*filePanelOkButton.fromVert:		filePanelText",
"Xarchie*filePanelOkButton.vertDistance:		10",
"Xarchie*filePanelOkButton.horizDistance:	100",
"Xarchie*filePanelCancelButton.label:		Cancel",
"Xarchie*filePanelCancelButton.fromVert:		filePanelText",
"Xarchie*filePanelCancelButton.fromHoriz:	filePanelOkButton",
"Xarchie*filePanelCancelButton.vertDistance:	10",
"Xarchie*filePanelCancelButton.horizDistance:	30",
"Xarchie*helpShell.title:		Xarchie Help Panel",
"Xarchie*helpShell.translations:#override\\n\
	<Message>WM_PROTOCOLS:	help-done()\\n",
"Xarchie*helpForm*Text*borderWidth:	1",
"Xarchie*helpForm.Label*resizable:	True",
"Xarchie*helpForm*helpLabel.borderWidth:	0",
"Xarchie*helpForm*helpViewport.fromVert:	helpLabel",
"Xarchie*helpForm*helpViewport.width:	250",
"Xarchie*helpForm*helpViewport.height:	150",
"Xarchie*helpForm*helpViewport.left:	chainLeft",
"Xarchie*helpForm*helpViewport.right:	chainLeft",
"Xarchie*helpForm*helpList*font:			xarchieFont",
"Xarchie*helpForm*helpList*verticalList:		true",
"Xarchie*helpForm*helpList*defaultColumns:	1",
"Xarchie*helpForm*helpList*forceColumns:		true",
"Xarchie*helpForm*helpList*maxSelectable: 	1",
"Xarchie*helpForm*helpList*height:		150",
"Xarchie*helpForm*helpText.fromVert:	helpLabel",
"Xarchie*helpForm*helpText.fromHoriz:	helpViewport",
"Xarchie*helpForm*helpText.width:	350",
"Xarchie*helpForm*helpText.height:	150",
"Xarchie*helpForm*helpText.left:			chainLeft",
"Xarchie*helpForm*helpText*editType:		read",
"Xarchie*helpForm*helpText.scrollVertical:	always",
"Xarchie*helpForm*helpText.scrollHorizontal:	never",
"Xarchie*helpForm*helpText*Scrollbar.thickness:	14",
"Xarchie*helpForm*helpDoneButton.label:		Done",
"Xarchie*helpForm*helpDoneButton.fromVert:	helpViewport",
"Xarchie*helpForm*helpDoneButton.translations:#override\\n\
	<BtnDown>,<BtnUp>:	help-done() \\n",
"Xarchie*helpForm*helpPrevButton.label:		Previous",
"Xarchie*helpForm*helpPrevButton.fromVert:	helpViewport",
"Xarchie*helpForm*helpPrevButton.fromHoriz:	helpDoneButton",
"Xarchie*helpForm*helpPrevButton.translations:#override\\n\
	<BtnDown>,<BtnUp>:	help-prev() \\n",
"Xarchie*helpForm*helpNextButton.label:		Next",
"Xarchie*helpForm*helpNextButton.fromVert:	helpViewport",
"Xarchie*helpForm*helpNextButton.fromHoriz:	helpPrevButton",
"Xarchie*helpForm*helpNextButton.translations:#override\\n\
	<BtnDown>,<BtnUp>:	help-next() \\n",
"Xarchie*helpForm*helpDownButton.label:		Down",
"Xarchie*helpForm*helpDownButton.fromVert:	helpViewport",
"Xarchie*helpForm*helpDownButton.fromHoriz:	helpViewport",
"Xarchie*helpForm*helpDownButton.translations:#override\\n\
	<BtnDown>,<BtnUp>:	help-down() \\n",
"Xarchie*helpForm*helpUpButton.label:		Up",
"Xarchie*helpForm*helpUpButton.fromVert:		helpViewport",
"Xarchie*helpForm*helpUpButton.fromHoriz:	helpDownButton",
"Xarchie*helpForm*helpUpButton.translations:#override\\n\
	<BtnDown>,<BtnUp>:	help-up() \\n",
"Xarchie*viewForm.Command.top:		chainTop",
"Xarchie*viewForm.Command.bottom:	chainTop",
"Xarchie*viewForm.Command.right:		chainLeft",
"Xarchie*viewForm.Command.left:		chainLeft",
"Xarchie*viewDoneButton.label:		Dismiss",
"Xarchie*viewDownButton.label:		Down",
"Xarchie*viewDownButton.fromHoriz:	viewDoneButton",
"Xarchie*viewUpButton.label:		Up",
"Xarchie*viewUpButton.fromHoriz:	viewDownButton",
"Xarchie*viewSaveButton.label:		Save",
"Xarchie*viewSaveButton.fromHoriz:	viewUpButton",
"Xarchie*viewText.fromVert:		viewDoneButton",
"Xarchie*viewText.top:			chainTop",
"Xarchie*viewText.left:			chainLeft",
"Xarchie*viewText.scrollVertical:	whenNeeded",
"Xarchie*viewText.width:			570",
"Xarchie*viewText.height:		320",
"Xarchie*viewText*Scrollbar.thickness:	14",
"Xarchie*viewSaveShell.title:	Xarchie Save Retrieved File",
"Xarchie*viewSaveLabel.label:			File:",
"Xarchie*viewSaveLabel.borderWidth:		0",
"Xarchie*viewSaveLabelText.fromHoriz:		viewSaveLabel",
"Xarchie*viewSaveLabelText.width:		250",
"Xarchie*viewSaveLabelText.borderWidth:		0",
"Xarchie*viewSaveLabelText*editType:		read",
"Xarchie*viewSaveFileChooser.width:		300",
"Xarchie*viewSaveTextLabel.label:		Save to:",
"Xarchie*viewSaveText.fromHoriz:			viewSaveTextLabel",
"Xarchie*viewSaveText.width:			240",
"Xarchie*viewSaveText.translations:#override\\n\
	<Enter>:	display-caret(True) \\n\
	<Leave>:	display-caret(False) \\n\
	<Key>Return:	no-op()\\n",
"Xarchie*viewSaveOkButton.label:			Ok",
"Xarchie*viewSaveOkButton.fromVert:		viewSaveText",
"Xarchie*viewSaveOkButton.vertDistance:		10",
"Xarchie*viewSaveOkButton.horizDistance:		80",
"Xarchie*viewSaveCancelButton.label:		Cancel",
"Xarchie*viewSaveCancelButton.fromVert:		viewSaveText",
"Xarchie*viewSaveCancelButton.fromHoriz:		viewSaveOkButton",
"Xarchie*viewSaveCancelButton.vertDistance:	10",
"Xarchie*viewSaveCancelButton.horizDistance:	30",
"Xarchie*aboutShell.title:		About Xarchie",
"Xarchie*aboutShell.translations:#override\\n\
	<Message>WM_PROTOCOLS:	about-done()\\n",
"Xarchie*aboutShell*aboutLabel0.label:	Xarchie 2.0",
"Xarchie*aboutShell*aboutLabel0.width:	200",
"Xarchie*aboutShell*aboutLabel1.label:	George Ferguson",
"Xarchie*aboutShell*aboutLabel1.fromVert:aboutLabel0",
"Xarchie*aboutShell*aboutLabel1.width:	200",
"Xarchie*aboutShell*aboutLabel2.label:	ferguson@cs.rochester.edu",
"Xarchie*aboutShell*aboutLabel2.fromVert:aboutLabel1",
"Xarchie*aboutShell*aboutLabel2.width:	200",
"Xarchie*aboutShell*aboutLabel3.fromHoriz:	aboutLabel2",
"Xarchie*aboutShell*aboutLabel3.horizDistance:	20",
"Xarchie*aboutShell*aboutLabel4.label:	For info about Archie: info@bunyip.com",
"Xarchie*aboutShell*aboutLabel4.fromVert:	aboutLabel2",
"Xarchie*aboutShell*aboutLabel4.vertDistance:	10",
"Xarchie*aboutShell*aboutLabel5.label:	\\ \\ \\ \\ \\ \\ \\ \\ \\ \\ \\ \\ \\ Prospero: info-prospero@isi.edu",
"Xarchie*aboutShell*aboutLabel5.fromVert:	aboutLabel4",
"Xarchie*aboutShell*aboutLabel6.label:	\\ \\ Archie servers: archie-admin@<archie-host>",
"Xarchie*aboutShell*aboutLabel6.fromVert:	aboutLabel5",
"Xarchie*aboutShell*aboutDoneButton.label:	Dismiss",
"Xarchie*aboutShell*aboutDoneButton.fromVert:	aboutLabel6",
"Xarchie*aboutShell*aboutDoneButton.translations:#override\\n\
	<BtnDown>,<BtnUp>:	about-done() \\n",
"Xarchie*ftpTraceShell.title:		Xarchie Ftp Trace",
"Xarchie*ftpTraceShell.translations:#override\\n\
	<Message>WM_PROTOCOLS:	ftp-trace-done()\\n",
"Xarchie*ftpTraceShell*ftpTraceDismissButton.label:	Dismiss",
"Xarchie*ftpTraceShell*ftpTraceDismissButton.translations:#override\\n\
	<BtnDown>,<BtnUp>:	ftp-trace-done() \\n",
"Xarchie*ftpTraceShell*ftpTraceText.fromVert:		ftpTraceDismissButton",
"Xarchie*ftpTraceShell*ftpTraceText.top:			chainTop",
"Xarchie*ftpTraceShell*ftpTraceText.left:		chainLeft",
"Xarchie*ftpTraceShell*ftpTraceText.scrollVertical:	whenNeeded",
"Xarchie*ftpTraceShell*ftpTraceText.Scrollbar.thickness:	14",
"Xarchie*ftpTraceShell*ftpTraceText.width:		570",
"Xarchie*ftpTraceShell*ftpTraceText.height:		320",
"Xarchie*SmeBSB.font:		xarchieFont",
"Xarchie*menuLabel.font:		xarchieBoldFont",
"Xarchie*menuLabel.leftMargin:	4",
"Xarchie*fileMenu.label:		File",
"Xarchie*fileMenuItem0.label:	About...",
"Xarchie*fileMenuItem1.label:	Open",
"Xarchie*fileMenuItem2.label:	Get...",
"Xarchie*fileMenuItem3.label:	Save...",
"Xarchie*fileMenuItem4.label:	Load...",
"Xarchie*fileMenuItem5.label:	Write...",
"Xarchie*fileMenuItem6.label:	Quit",
"Xarchie*queryMenu.label:	Query",
"Xarchie*queryMenuItem0.label:	Query Item",
"Xarchie*queryMenuItem1.label:	Query Host",
"Xarchie*queryMenuItem2.label:	Query Location",
"Xarchie*settingsMenu.label:		Settings",
"Xarchie*settingsMenu.translations:#override\\n\
	<BtnMotion>: highlight() settings-submenu() \\n",
"Xarchie*settingsMenuItem0.label:	Archie Host >",
"Xarchie*settingsMenuItem1.label:	Search Type >",
"Xarchie*settingsMenuItem2.label:	Sort Type   >",
"Xarchie*settingsMenuItem3.label:	Nice Level  >",
"Xarchie*settingsMenuItem4.label:	Other...",
"Xarchie*setSearchMenu.label:	Search Type",
"Xarchie*searchMenu.label:	Search Type",
"Xarchie*searchMenuItem0.label:	Exact",
"Xarchie*searchMenuItem1.label:	Substr",
"Xarchie*searchMenuItem2.label:	Subcase",
"Xarchie*searchMenuItem3.label:	Regexp",
"Xarchie*searchMenuItem4.label:	ExactSubstr",
"Xarchie*searchMenuItem5.label:	ExactSubcase",
"Xarchie*searchMenuItem6.label:	ExactRegexp",
"Xarchie*searchMenu*leftMargin:	15",
"Xarchie*searchMenu.translations:#override\\n\
     <EnterWindow>:     highlight()             \\n\
     <LeaveWindow>:     unhighlight() MenuPopdown() \\n\
     <BtnMotion>:       highlight()             \\n\
     <BtnUp>:           notify() unhighlight() MenuPopdown()",
"Xarchie*setSortMenu.label:	Sort Type",
"Xarchie*sortMenu.label:		Sort Type",
"Xarchie*sortMenuItem0.label:	By Name",
"Xarchie*sortMenuItem1.label:	By Date",
"Xarchie*sortMenuItem2.label:	By Weight",
"Xarchie*sortMenu*leftMargin:	15",
"Xarchie*sortMenu.translations:#override\\n\
     <EnterWindow>:     highlight()             \\n\
     <LeaveWindow>:     unhighlight() MenuPopdown() \\n\
     <BtnMotion>:       highlight()             \\n\
     <BtnUp>:           notify() unhighlight() MenuPopdown()",
"Xarchie*setHostMenu.label:	Archie Host",
"Xarchie*hostMenu.label:		Archie Host",
"Xarchie*hostMenuItem0.label:  archie.sura.net(1526)     USA (MD)",
"Xarchie*hostMenuItem1.label:  archie.sura.net           USA (MD)",
"Xarchie*hostMenuItem2.label:  archie.ans.net            USA (NY)",
"Xarchie*hostMenuItem3.label:  archie.rutgers.edu        USA (NJ)",
"Xarchie*hostMenuItem4.label:  archie.unl.edu            USA (NE)",
"Xarchie*hostMenuItem5.label:  archie.internic.net       USA (NJ)",
"Xarchie*hostMenuItem6.label:  archie.au                 Australia",
"Xarchie*hostMenuItem7.label:  archie.uni-linz.ac.at     Austria",
"Xarchie*hostMenuItem8.label:  archie.univie.ac.at       Austria",
"Xarchie*hostMenuItem9.label:  archie.cs.mcgill.ca       Canada",
"Xarchie*hostMenuItem10.label: archie.uqam.ca            Canada",
"Xarchie*hostMenuItem11.label: archie.funet.fi           Finland",
"Xarchie*hostMenuItem12.label: archie.univ-rennes1.fr    France",
"Xarchie*hostMenuItem13.label: archie.th-darmstadt.de    Germany",
"Xarchie*hostMenuItem14.label: archie.ac.il              Israel",
"Xarchie*hostMenuItem15.label: archie.unipi.it           Italy",
"Xarchie*hostMenuItem16.label: archie.wide.ad.jp         Japan",
"Xarchie*hostMenuItem17.label: archie.hana.nm.kr         Korea",
"Xarchie*hostMenuItem18.label: archie.sogang.ac.kr       Korea",
"Xarchie*hostMenuItem19.label: archie.uninett.no         Norway",
"Xarchie*hostMenuItem20.label: archie.rediris.es         Spain",
"Xarchie*hostMenuItem21.label: archie.luth.se            Sweden",
"Xarchie*hostMenuItem22.label: archie.switch.ch          Switzerland",
"Xarchie*hostMenuItem23.label: archie.twnic.net          Taiwan",
"Xarchie*hostMenuItem24.label: archie.ncu.edu.tw         Taiwan",
"Xarchie*hostMenuItem25.label: archie.doc.ic.ac.uk       United Kingdom",
"Xarchie*hostMenuItem26.label: archie.hensa.ac.uk        United Kingdom",
"Xarchie*numHosts:               27",
"Xarchie*hostMenu*leftMargin:	15",
"Xarchie*hostMenu.translations:#override\\n\
     <EnterWindow>:     highlight()             \\n\
     <LeaveWindow>:     unhighlight() MenuPopdown() \\n\
     <BtnMotion>:       highlight()             \\n\
     <BtnUp>:           notify() unhighlight() MenuPopdown()",
"Xarchie*setNiceMenu.label:	Nice Level",
"Xarchie*niceMenu.label:		Nice Level",
"Xarchie*niceMenuItem0.label:	Default",
"Xarchie*niceMenuItem1.label:	Nice",
"Xarchie*niceMenuItem2.label:	Nicer",
"Xarchie*niceMenuItem3.label:	Very Nice",
"Xarchie*niceMenuItem4.label:	Extremely Nice",
"Xarchie*niceMenuItem5.label:	Nicest",
"Xarchie*niceMenu*leftMargin:	15",
"Xarchie*niceMenu.translations:#override\\n\
     <EnterWindow>:     highlight()             \\n\
     <LeaveWindow>:     unhighlight() MenuPopdown() \\n\
     <BtnMotion>:       highlight()             \\n\
     <BtnUp>:           notify() unhighlight() MenuPopdown()",
"Xarchie*setAutoScrollMenuItem0.label:	Scroll",
"Xarchie*setAutoScrollMenuItem1.label:	Don't scroll",
"Xarchie*ftpTypeMenuItem0.label:		Binary",
"Xarchie*ftpTypeMenuItem1.label:		Ascii",
"Xarchie*ftpPromptMenuItem0.label:	Prompt",
"Xarchie*ftpPromptMenuItem1.label:	Don't prompt",
"Xarchie*ftpTraceMenuItem0.label:	Trace",
"Xarchie*ftpTraceMenuItem1.label:	Don't trace",
"Xarchie*ftpStripMenuItem0.label:	Strip",
"Xarchie*ftpStripMenuItem1.label:	Don't strip",
"Xarchie*filePanelWriteModeMenuItem0.label:	One entry per line",
"Xarchie*filePanelWriteModeMenuItem1.label:	Pretty-printed",
"Xarchie*filePanelWriteModeMenu*leftMargin:	15",
"Xarchie*allowShellResize:		True",
"Xarchie*Dialog*Label.resizable:		True",
"Xarchie*Dialog*Text.width:		250",
"Xarchie*Dialog*Text.scrollHorizontal:	never",
"Xarchie*alertShell.title:		Xarchie Alert",
"Xarchie*alertButton0.label:		Ok",
"Xarchie*confirmShell.title:		Xarchie Confirm",
"Xarchie*confirmButton0.label:		Yes",
"Xarchie*confirmButton1.label:		No",
"Xarchie*ftpPromptShell.title:		Xarchie FTP Prompt",
"Xarchie*ftpPromptButton0.label:		Yes",
"Xarchie*ftpPromptButton1.label:		No",
"Xarchie*ftpPromptButton2.horizDistance:	50",
"Xarchie*ftpPromptButton2.label:		All",
"Xarchie*ftpPromptButton3.label:		Abort",
"Xarchie*settingsConfirmShell.title:	Xarchie Confirm",
"Xarchie*settingsConfirmButton0.label:	Dismiss",
"Xarchie*settingsConfirmButton1.label:	Apply",
"Xarchie*settingsConfirmButton2.label:	Cancel",
"Xarchie.color*background:			powder blue",
"Xarchie.color*foreground:			blue",
"Xarchie.color*SimpleMenu*background:		wheat",
"Xarchie.color*SimpleMenu*foreground:		blue",
"Xarchie.color*Command*background:		wheat",
"Xarchie.color*MenuButton*background:		wheat",
"Xarchie.color*Text*background:			wheat",
"Xarchie.color*statusText*background:		powder blue",
"Xarchie.color*viewSaveLabelText*background:	powder blue",
"Xarchie.color*browserForm.background:		gray",
"Xarchie.color*browserForm*Command.background:	gray",
"Xarchie.color*browserForm*Paned*background:	gray91",
"Xarchie.color*List*background:			gray91",
"Xarchie.color*List*foreground:			blue",
"Xarchie.color*XfwfMultiList*highlightBackground:blue",
"Xarchie.color*XfwfMultiList*highlightForeground:white",
"Xarchie.color*stringForm*Text*background:	light gray",
"Xarchie.color*stringForm*searchText*background:	wheat",
"Xarchie.color*helpForm*List.background:		gray91",
"Xarchie.color*helpForm*Text*background:		gray91",
"Xarchie.color*alertDialog*Label.foreground:	red",
"Xarchie.color*alertDialog*background:		pink",
"Xarchie.color*alertButton0.background:		green",
"Xarchie.color*confirmDialog*Label.foreground:	blue",
"Xarchie.color*confirmDialog*background:		light blue",
"Xarchie.color*confirmButton0.background:	green",
"Xarchie.color*confirmButton1.background:	red",
"Xarchie.color*fileOkButton*background:		green",
"Xarchie.color*fileCancelButton*background:	red",
"Xarchie.color*ftpTraceText*background:		powder blue",
"Xarchie.color*ftpPromptButton0*background:	green",
"Xarchie.color*ftpPromptButton1*background:	red",
"Xarchie.color*ftpPromptButton2*background:	green",
"Xarchie.color*ftpPromptButton3*background:	red",
"Xarchie.gray*background:			gray55",
"Xarchie.gray*foreground:			gray20",
"Xarchie.gray*SimpleMenu*background:		gray70",
"Xarchie.gray*SimpleMenu*foreground:		gray20",
"Xarchie.gray*Command*background:		gray80",
"Xarchie.gray*MenuButton*background:		gray80",
"Xarchie.gray*Text*background:			gray80",
"Xarchie.gray*Dialog*Label.foreground:		gray20",
"Xarchie.gray*Dialog*background:			gray90",
"Xarchie.gray*Dialog*Command.background:		gray50",
"Xarchie.gray*statusText*background:		gray55",
"Xarchie.gray*viewSaveLabelText*background:	gray55",
"Xarchie.gray*browserForm.background:		gray90",
"Xarchie.gray*browserForm*Command.background:	gray90",
"Xarchie.gray*browserForm*Paned*background:	gray90",
"Xarchie.gray*List*background:			gray90",
"Xarchie.gray*XfwfMultiList*highlightBackground:	gray20",
"Xarchie.gray*XfwfMultiList*highlightForeground:	white",
"Xarchie.gray*stringForm*Text*background:	gray80",
"Xarchie.gray*stringForm*searchText*background:	gray80",
"Xarchie.gray*helpForm*List.background:		gray90",
"Xarchie.gray*helpForm*Text*background:		gray90",
"Xarchie.gray*ftpTraceText*background:		gray55",
